package com.ruoyi.tdengine.api.factory;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.tdengine.api.RemoteTdEngineService;
import com.ruoyi.tdengine.api.domain.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;

import java.util.Map;

@Component
public class RemoteTdEngineFallbackFactory implements FallbackFactory<RemoteTdEngineService> {

    private static final Logger log = LoggerFactory.getLogger(RemoteTdEngineFallbackFactory.class);
    @Override
    public RemoteTdEngineService create(Throwable throwable) {
        return new RemoteTdEngineService()
        {
            @Override
            public R<?> createDataBase(String databaseName) {
                return R.fail("创建数据库失败:" + throwable.getMessage());
            }

            @Override
            public R<?> createSuperTable(TdSuperTableVo tdSuperTableVo) {
                return R.fail("创建超级表失败:" + throwable.getMessage());
            }

            @Override
            public R<?> createTable(TdTableVo tdTableVo) {
                return R.fail("创建子表失败:" + throwable.getMessage());
            }

            @Override
            public R<?> addSuperTableColumn(TdSuperTableVo tdSuperTableVo) {
                return R.fail("添加超级表Column失败:" + throwable.getMessage());
            }

            @Override
            public R<?> dropColumnForSuperTable(TdSuperTableVo tdSuperTableVo) {
                return R.fail("删除超级表Column失败:" + throwable.getMessage());
            }

            @Override
            public R<?> alterTableTag(AlterTagVo alterTagVo) {
                return R.fail("修改子表tag值失败:" + throwable.getMessage());
            }

            @Override
            public R<?> insertTable(TdTableVo tdTableVo) {
                return R.fail("插入数据失败:" + throwable.getMessage());
            }

            @Override
            public R<?> getLatestData(TdSelectDto tdSelectDto) {
                return R.fail("获取子表最新数据失败:" + throwable.getMessage());
            }

            @Override
            public R<Map<String, Map<String, Object>>> getLatestDataByTags(TdSelectDto tdSelectDto) {
                return R.fail("根据tags获取超级表最新数据失败:" + throwable.getMessage());
            }

            @Override
            public R<?> getHistoryData(TdHistorySelectDto tdHistorySelectDto) {
                return R.fail("获取历史数据失败:" + throwable.getMessage());
            }

            @Override
            public R<?> getCountOfHistoryData(TdHistorySelectDto tdHistorySelectDto) {
                return R.fail("获取历史数据数量失败:" + throwable.getMessage());
            }

        };
    }
}
