package com.ruoyi.business.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.business.domain.HwDevice;
import com.ruoyi.business.service.IHwDeviceService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 设备信息Controller
 * 
 * @author xins
 * @date 2023-08-24
 */
@RestController
@RequestMapping("/device")
public class HwDeviceController extends BaseController
{
    @Autowired
    private IHwDeviceService hwDeviceService;

    /**
     * 查询设备信息列表
     */
    @RequiresPermissions("business:device:list")
    @GetMapping("/list")
    public TableDataInfo list(HwDevice hwDevice)
    {
        startPage();
        List<HwDevice> list = hwDeviceService.selectHwDeviceList(hwDevice);
        return getDataTable(list);
    }

    /**
     * 导出设备信息列表
     */
    @RequiresPermissions("business:device:export")
    @Log(title = "设备信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HwDevice hwDevice)
    {
        List<HwDevice> list = hwDeviceService.selectHwDeviceList(hwDevice);
        ExcelUtil<HwDevice> util = new ExcelUtil<HwDevice>(HwDevice.class);
        util.exportExcel(response, list, "设备信息数据");
    }

    /**
     * 获取设备信息详细信息
     */
    @RequiresPermissions("business:device:query")
    @GetMapping(value = "/{deviceId}")
    public AjaxResult getInfo(@PathVariable("deviceId") Long deviceId)
    {
        return success(hwDeviceService.selectHwDeviceByDeviceId(deviceId));
    }

    /**
     * 新增设备信息
     */
    @RequiresPermissions("business:device:add")
    @Log(title = "设备信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HwDevice hwDevice)
    {
        return toAjax(hwDeviceService.insertHwDevice(hwDevice));
    }

    /**
     * 修改设备信息
     */
    @RequiresPermissions("business:device:edit")
    @Log(title = "设备信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HwDevice hwDevice)
    {
        return toAjax(hwDeviceService.updateHwDevice(hwDevice));
    }

    /**
     * 删除设备信息
     */
    @RequiresPermissions("business:device:remove")
    @Log(title = "设备信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceIds}")
    public AjaxResult remove(@PathVariable Long[] deviceIds)
    {
        return toAjax(hwDeviceService.deleteHwDeviceByDeviceIds(deviceIds));
    }
}
