package com.ruoyi.business.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.HwSceneMapper;
import com.ruoyi.business.domain.HwScene;
import com.ruoyi.business.service.IHwSceneService;

/**
 * 场景信息Service业务层处理
 * 
 * @author xins
 * @date 2023-08-23
 */
@Service
public class HwSceneServiceImpl implements IHwSceneService 
{
    @Autowired
    private HwSceneMapper hwSceneMapper;

    /**
     * 查询场景信息
     * 
     * @param sceneId 场景信息主键
     * @return 场景信息
     */
    @Override
    public HwScene selectHwSceneBySceneId(Long sceneId)
    {
        return hwSceneMapper.selectHwSceneBySceneId(sceneId);
    }

    /**
     * 查询场景信息列表
     * 
     * @param hwScene 场景信息
     * @return 场景信息
     */
    @Override
    public List<HwScene> selectHwSceneList(HwScene hwScene)
    {
        return hwSceneMapper.selectHwSceneList(hwScene);
    }

    /**
     * 新增场景信息
     * 
     * @param hwScene 场景信息
     * @return 结果
     */
    @Override
    public int insertHwScene(HwScene hwScene)
    {
        hwScene.setCreateTime(DateUtils.getNowDate());
        return hwSceneMapper.insertHwScene(hwScene);
    }

    /**
     * 修改场景信息
     * 
     * @param hwScene 场景信息
     * @return 结果
     */
    @Override
    public int updateHwScene(HwScene hwScene)
    {
        hwScene.setUpdateTime(DateUtils.getNowDate());
        return hwSceneMapper.updateHwScene(hwScene);
    }

    /**
     * 批量删除场景信息
     * 
     * @param sceneIds 需要删除的场景信息主键
     * @return 结果
     */
    @Override
    public int deleteHwSceneBySceneIds(Long[] sceneIds)
    {
        return hwSceneMapper.deleteHwSceneBySceneIds(sceneIds);
    }

    /**
     * 删除场景信息信息
     * 
     * @param sceneId 场景信息主键
     * @return 结果
     */
    @Override
    public int deleteHwSceneBySceneId(Long sceneId)
    {
        return hwSceneMapper.deleteHwSceneBySceneId(sceneId);
    }
}
