/*
 * Copyright (c) 2019-2029, Dreamlu 卢春梦 (596392912@qq.com & dreamlu.net).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hw.mqtt.service;


import java.util.List;

/**
 * mqtt broker 服务
 *
 * @author L.cm
 */
public interface IMqttBrokerService {

	/**
	 * 获取在线客户端数量
	 * @author WenJY
	 * @date 2023-03-14 13:51
	 * @return long
	 */
	long getOnlineClientSize();

	/**
	 * 获取所有在线的客户端
	 * @author WenJY
	 * @date 2023-03-14 13:51
	 * @return java.util.List<java.lang.String>
	 */
	List<String> getOnlineClients();

	/**
	 * 向指定主题发送消息
	 * @author WenJY
	 * @date 2023-03-14 13:50
	 * @param topic
	 * @param payload
	 * @return boolean
	 */
	boolean publish(String topic,String payload);

	/**
	 * 主动关闭指定客户端连接
	 * @author WenJY
	 * @date 2023-03-18 9:23
	 * @param clientId
	 */
	boolean closeClientById(String clientId);
}
